global.rtest(X, listw, k = 1, nperm = 499)listw. Can be obtained easily
using the function chooseCN.randtest.
The reference distribution of these statistics are obtained by randomly permuting the rows of X.
These tests were originally part of the adegenet package for R.